@@ -70,7 +70,8 @@ use App::Dochazka::CLI::Commands::History qw(
 use App::Dochazka::CLI::Commands::Interval qw(
     interval_date
     interval_date_date1
-    interval_fillup_tsrange
+    interval_datelist
+    interval_tsrange
     interval_month
     interval_num_num1
     interval_promptdate
@@ -373,18 +374,10 @@ our $dispatch_map = {
     "PUT INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
     "POST INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
     "DELETE INTERVAL EID _NUM _TSRANGE" => \&_method_interval_eid_tsrange,
-    "GET INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
-    "PUT INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
-    "POST INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
-    "DELETE INTERVAL FILLUP EID _NUM _TSRANGE" => \&_method_interval_fillup_eid,
-    "GET INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
-    "PUT INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
-    "POST INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
-    "DELETE INTERVAL FILLUP NICK _TERM _TSRANGE" => \&_method_interval_fillup_nick,
-    "GET INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
-    "PUT INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
-    "POST INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
-    "DELETE INTERVAL FILLUP SELF _TSRANGE" => \&_method_interval_fillup_self,
+    "GET INTERVAL FILLUP" => \&_method_interval_fillup,
+    "PUT INTERVAL FILLUP" => \&_method_interval_fillup,
+    "POST INTERVAL FILLUP" => \&_method_interval_fillup,
+    "DELETE INTERVAL FILLUP" => \&_method_interval_fillup,
     "GET INTERVAL IID _NUM" => \&_method_interval_iid,
     "PUT INTERVAL IID _NUM" => \&_method_interval_iid,
     "POST INTERVAL IID _NUM" => \&_method_interval_iid,
@@ -651,8 +644,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH" => \&interval_promptdate,
     "INTERVAL FILLUP" => \&interval_promptdate,
     "EMPLOYEE_SPEC INTERVAL FILLUP" => \&interval_promptdate,
-    "INTERVAL FILLUP COMMIT" => \&interval_promptdate,
-    "EMPLOYEE_SPEC INTERVAL FILLUP COMMIT" => \&interval_promptdate,
+    "INTERVAL FILLUP DRY_RUN" => \&interval_promptdate,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN" => \&interval_promptdate,
     "INTERVAL SUMMARY" => \&interval_promptdate,
     "EMPLOYEE_SPEC INTERVAL SUMMARY" => \&interval_promptdate,
     "INTERVAL REPORT" => \&interval_promptdate,
@@ -666,8 +659,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE" => \&interval_date,
     "INTERVAL FILLUP _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE" => \&interval_date,
-    "INTERVAL FILLUP _DATE COMMIT" => \&interval_date,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE COMMIT" => \&interval_date,
+    "INTERVAL FILLUP DRY_RUN _DATE" => \&interval_date,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATE" => \&interval_date,
     "INTERVAL SUMMARY _DATE" => \&interval_date,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE" => \&interval_date,
     "INTERVAL REPORT _DATE" => \&interval_date,
@@ -681,8 +674,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL FILLUP _DATE _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _DATE1" => \&interval_date_date1,
-    "INTERVAL FILLUP _DATE _DATE1 COMMIT" => \&interval_date_date1,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _DATE1 COMMIT" => \&interval_date_date1,
+    "INTERVAL FILLUP DRY_RUN _DATE _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL SUMMARY _DATE _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _DATE1" => \&interval_date_date1,
     "INTERVAL REPORT _DATE _DATE1" => \&interval_date_date1,
@@ -696,8 +689,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL FILLUP _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1" => \&interval_date_date1,
-    "INTERVAL FILLUP _DATE _HYPHEN _DATE1 COMMIT" => \&interval_date_date1,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _DATE _HYPHEN _DATE1 COMMIT" => \&interval_date_date1,
+    "INTERVAL FILLUP DRY_RUN _DATE _HYPHEN _DATE1" => \&interval_date_date1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL SUMMARY _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _DATE _HYPHEN _DATE1" => \&interval_date_date1,
     "INTERVAL REPORT _DATE _HYPHEN _DATE1" => \&interval_date_date1,
@@ -711,8 +704,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _MONTH" => \&interval_month,
     "INTERVAL FILLUP _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH" => \&interval_month,
-    "INTERVAL FILLUP _MONTH COMMIT" => \&interval_month,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH COMMIT" => \&interval_month,
+    "INTERVAL FILLUP DRY_RUN _MONTH" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _MONTH" => \&interval_month,
     "INTERVAL SUMMARY _MONTH" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH" => \&interval_month,
     "INTERVAL REPORT _MONTH" => \&interval_month,
@@ -726,8 +719,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _MONTH _NUM" => \&interval_month,
     "INTERVAL FILLUP _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _NUM" => \&interval_month,
-    "INTERVAL FILLUP _MONTH _NUM COMMIT" => \&interval_month,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _NUM COMMIT" => \&interval_month,
+    "INTERVAL FILLUP DRY_RUN _MONTH _NUM" => \&interval_month,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _MONTH _NUM" => \&interval_month,
     "INTERVAL SUMMARY _MONTH _NUM" => \&interval_month,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _MONTH _NUM" => \&interval_month,
     "INTERVAL REPORT _MONTH _NUM" => \&interval_month,
@@ -741,8 +734,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _NUM" => \&interval_num_num1,
     "INTERVAL FILLUP _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM" => \&interval_num_num1,
-    "INTERVAL FILLUP _NUM COMMIT" => \&interval_num_num1,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _NUM COMMIT" => \&interval_num_num1,
+    "INTERVAL FILLUP DRY_RUN _NUM" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _NUM" => \&interval_num_num1,
     "INTERVAL SUMMARY _NUM" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _NUM" => \&interval_num_num1,
     "INTERVAL REPORT _NUM" => \&interval_num_num1,
@@ -756,8 +749,8 @@ our $dispatch_map = {
     "EMPLOYEE_SPEC INTERVAL FETCH _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL FILLUP _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL FILLUP _NUM _NUM1" => \&interval_num_num1,
-    "INTERVAL FILLUP _NUM _NUM1 COMMIT" => \&interval_num_num1,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _NUM _NUM1 COMMIT" => \&interval_num_num1,
+    "INTERVAL FILLUP DRY_RUN _NUM _NUM1" => \&interval_num_num1,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL SUMMARY _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL SUMMARY _NUM _NUM1" => \&interval_num_num1,
     "INTERVAL REPORT _NUM _NUM1" => \&interval_num_num1,
@@ -765,14 +758,23 @@ our $dispatch_map = {
     "INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
     "EMPLOYEE_SPEC INTERVAL DELETE _NUM _NUM1" => \&interval_num_num1,
 
-    "INTERVAL FILLUP _TSRANGE" => \&interval_fillup_tsrange,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE" => \&interval_fillup_tsrange,
-    "INTERVAL FILLUP _TSRANGE COMMIT" => \&interval_fillup_tsrange,
-    "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE COMMIT" => \&interval_fillup_tsrange,
-    "INTERVAL SUMMARY _TSRANGE" => \&interval_fillup_tsrange,
-    "EMPLOYEE_SPEC INTERVAL SUMMARY _TSRANGE" => \&interval_fillup_tsrange,
-    "INTERVAL REPORT _TSRANGE" => \&interval_fillup_tsrange,
-    "EMPLOYEE_SPEC INTERVAL REPORT _TSRANGE" => \&interval_fillup_tsrange,
+    "INTERVAL FILLUP _TSRANGE" => \&interval_tsrange,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _TSRANGE" => \&interval_tsrange,
+    "INTERVAL FILLUP DRY_RUN _TSRANGE" => \&interval_tsrange,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _TSRANGE" => \&interval_tsrange,
+    "INTERVAL SUMMARY _TSRANGE" => \&interval_tsrange,
+    "EMPLOYEE_SPEC INTERVAL SUMMARY _TSRANGE" => \&interval_tsrange,
+    "INTERVAL REPORT _TSRANGE" => \&interval_tsrange,
+    "EMPLOYEE_SPEC INTERVAL REPORT _TSRANGE" => \&interval_tsrange,
+
+    "INTERVAL FILLUP _DATELIST" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _DATELIST" => \&interval_datelist,
+    "INTERVAL FILLUP DRY_RUN _DATELIST" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _DATELIST" => \&interval_datelist,
+    "INTERVAL FILLUP _MONTH _DATELIST" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP _MONTH _DATELIST" => \&interval_datelist,
+    "INTERVAL FILLUP DRY_RUN _MONTH _DATELIST" => \&interval_datelist,
+    "EMPLOYEE_SPEC INTERVAL FILLUP DRY_RUN _MONTH _DATELIST" => \&interval_datelist,
 
     # add/insert new intervals
     "INTERVAL _TIME _TIME1 _TERM" => \&interval_new_time_time1,
